@@ -1,6 +1,5 @@
 BASE_REQUIRED_FEATURES = [
     "address",
-    'approxSQFT',
     "bedroomsTotal",
     "bathroomsFull",
     "bathroomsTotal",
@@ -18,7 +17,6 @@ CONDO_ONLY_REQUIRED_FEATURES = [
     "associationFee",
     "bedroomsStandard",
     "buildingPlaceId",
-    "entryLevel",
     "unitNumber",
 ]
 
